@@ -1,6 +1,6 @@
-from MemoryGame import MemoryGame
-from GuessGame import GuessGame
-from CurrencyRGame import CurrencyRGame
+from .MemoryGame import MemoryGame
+from .GuessGame import GuessGame
+from .CurrencyRGame import CurrencyRGame
 
 
 class Factory:
